Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1702)

Unified Diff: net/base/x509_util_openssl_unittest.cc

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/base/x509_util_openssl.cc ('k') | net/http/http_cache.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/x509_util_openssl_unittest.cc
diff --git a/net/base/x509_util_openssl_unittest.cc b/net/base/x509_util_openssl_unittest.cc
index 599d0e4e278709fc5252d341b24f8dd9f9e3564c..20675057ecf0bee17f5cd1402e794cd39f76af41 100644
--- a/net/base/x509_util_openssl_unittest.cc
+++ b/net/base/x509_util_openssl_unittest.cc
@@ -10,18 +10,18 @@
namespace net {
// For OpenSSL, x509_util::CreateOriginBoundCertEC() is not yet implemented
// and should return false. This unit test ensures that a stub implementation
// is present.
-TEST(X509UtilOpenSSLTest, CreateOriginBoundCertNotImplemented) {
- std::string origin = "http://weborigin.com:443";
+TEST(X509UtilOpenSSLTest, CreateDomainBoundCertNotImplemented) {
+ std::string domain = "weborigin.com";
base::Time now = base::Time::Now();
scoped_ptr<crypto::ECPrivateKey> private_key(
crypto::ECPrivateKey::Create());
std::string der_cert;
- EXPECT_FALSE(x509_util::CreateOriginBoundCertEC(
+ EXPECT_FALSE(x509_util::CreateDomainBoundCertEC(
private_key.get(),
- origin, 1,
+ domain, 1,
now,
now + base::TimeDelta::FromDays(1),
&der_cert));
@@ -10,18 +10,18 @@
namespace net {
-// For OpenSSL, x509_util::CreateOriginBoundCertEC() is not yet implemented
+// For OpenSSL, x509_util::CreateDomainBoundCertEC() is not yet implemented
// and should return false. This unit test ensures that a stub implementation
// is present.
« no previous file with comments | « net/base/x509_util_openssl.cc ('k') | net/http/http_cache.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698